Module types

Module types 

Modules

actor
Idiomatic Rust from the Bluesky API actor types
commit
Helper types for deserialize commit data from the firehose.
feed
Helper types for bsky feed events, detailing user interactions with posts.
graph
Helper types for bsky graph events, detailing user connections. These events are emitted when a user does something related to another user.
operation

Structs

Blob
CidOld
ErrorFrame
ExternalLink
Image
MessageFrame
Post
A post on the network
PostData
ReplyRef
Video

Enums

Embed
Frame
Media

Traits

HttpService
Subscription

Functions

download_media
Downloads media associated with a post, returning bytes of the media