Modules
- actor
- Idiomatic Rust from the Bluesky API actor types
- commit
- Helper types for deserialize commit data from the firehose.
- feed
- Helper types for bsky feed events, detailing user interactions with posts.
- graph
- Helper types for bsky graph events, detailing user connections. These events are emitted when a user does something related to another user.
- operation
Structs
- Blob
- CidOld
- Error
Frame - External
Link - Image
- Message
Frame - Post
- A post on the network
- Post
Data - Reply
Ref - Video
Enums
Traits
Functions
- download_
media - Downloads media associated with a post, returning bytes of the media